//
//  ViewController.m
//  CustomSectionHeader
//
//  Created by Stephen Zaharuk on 4/7/15.
//  Copyright (c) 2015 Infragistics. All rights reserved.
//

#import "ViewController.h"
#import "igSalesmanItem.h"

@interface ViewController ()
{
    IGGridView  * _gridView;
    IGGridViewDataSourceHelper* _dsh;
}
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    _gridView = [[IGGridView alloc]initWithFrame:self.view.bounds];
    _gridView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    _gridView.sectionHeaderHeight = 50;
    [self.view addSubview:_gridView];
    
    
    _dsh = [[CustomDSH alloc]init];
    _dsh.groupingKey = @"territory";
    _dsh.data = [igSalesmanItem generateData:250];
    _dsh.allowSectionExpansion = YES;
    _gridView.dataSource = _dsh;
    
}


@end


@implementation CustomDSH

-(IGGridViewSectionCell *)gridView:(IGGridView *)gridView cellForSectionHeader:(NSInteger)section
{
    CustomSectionHeaderCell* cell = [gridView dequeueReusableCellWithIdentifier:@"shc"];
    
    if(!cell)
    {
        cell = [[CustomSectionHeaderCell alloc]initWithReuseIdentifier:@"shc"];
        cell.expandable = YES;
        cell.backgroundColor = [UIColor grayColor];
        cell.pressedBackgroundColor = [UIColor orangeColor];
    }
    
    // Look at your data to determine the state of the section:
    [cell setState:2];
    
    cell.textLabel.text = [self gridView:gridView titleForHeaderInSection:section];
    
    return cell;
    
}


@end

@interface CustomSectionHeaderCell()
{
    UIView* _circle;
    UIView* _placeHoldForMagnifyGlass;
}

@end

@implementation CustomSectionHeaderCell

-(instancetype)init
{
    self = [super init];
    if(self)
    {
        _circle = [[UIView alloc]init];
        _circle.userInteractionEnabled = NO;
        [self addSubview:_circle];
        
        _placeHoldForMagnifyGlass = [[UIView alloc]init];
        _placeHoldForMagnifyGlass.backgroundColor = [UIColor blueColor];
        [self addSubview:_placeHoldForMagnifyGlass];
        
        UITapGestureRecognizer* tapGesture = [[UITapGestureRecognizer alloc]initWithTarget:self action:@selector(magnifyTapped:)];
        [_placeHoldForMagnifyGlass addGestureRecognizer:tapGesture];
    }
    return self;
}

-(void)setState:(NSInteger)state
{
    if(state == 0)
        _circle.backgroundColor = [UIColor redColor];
    else if(state == 1)
        _circle.backgroundColor = [UIColor greenColor];
    else if(state == 2)
        _circle.backgroundColor = [UIColor yellowColor];
}

-(void)setupSize:(CGSize)size
{
    [super setupSize:size];
    
    CGFloat padding = 10;
    CGFloat circleSize = size.height - (padding*2);
    CGFloat left = padding;
    
    _circle.frame = CGRectMake(left, padding, circleSize, circleSize);
    _circle.layer.cornerRadius = circleSize/2;
    
    left += circleSize + padding;
    
    CGFloat labelWidth = size.width - (left* 2);
    
    self.textLabel.frame = CGRectMake(left, padding, labelWidth, circleSize);
    
    
    left += labelWidth + padding;
    
    _placeHoldForMagnifyGlass.frame = CGRectMake(left, padding, circleSize, circleSize);
}

-(void)magnifyTapped:(UITapGestureRecognizer*)gesture
{
    
}

@end